@@ -23,7 +23,6 @@ pub enum Lexem {
     And,
     Or,
     Not,
-    Group,
     Order,
     By,
     DescendingOrder,
@@ -50,6 +49,7 @@ pub struct Lexer {
     input_index: usize,
     char_index: isize,
     before_from: bool,
+    possible_search_root: bool,
     after_open: bool,
     after_where: bool,
     after_operator: bool,
@@ -62,6 +62,7 @@ impl Lexer {
             input_index: 0,
             char_index: 0,
             before_from: true,
+            possible_search_root: false,
             after_open: false,
             after_where: false,
             after_operator: false,
@@ -82,12 +83,12 @@ impl Lexer {
             let c;
             if self.char_index == -1 {
                 c = ' ';
-                self.char_index += 1;
             } else {
                 let input_char = input_part.chars().nth(self.char_index as usize);
                 if input_char.is_none() {
                     self.input_index += 1;
                     self.char_index = -1;
+                    self.possible_search_root = false;
                     continue;
                 }
                 c = input_char.unwrap();
@@ -135,7 +136,9 @@ impl Lexer {
                             if maybe_expr {
                                 break;
                             }
-                        } else if c == ' ' || c == ',' || is_paren_char(c) || self.is_op_char(c) {
+                        } else if (self.input.len() == 1 
+                                || (self.input.len() > 1 && !self.possible_search_root)) 
+                            && (c == ' ' || c == ',' || is_paren_char(c) || self.is_op_char(c)) {
                             break;
                         }
                     }
@@ -212,7 +215,6 @@ impl Lexer {
                 "or" => Some(Lexem::Or),
                 "and" => Some(Lexem::And),
                 "not" if self.after_where => Some(Lexem::Not),
-                "group" => Some(Lexem::Group),
                 "order" => Some(Lexem::Order),
                 "by" => Some(Lexem::By),
                 "asc" => self.next_lexem(),
@@ -227,6 +229,8 @@ impl Lexer {
             _ => None,
         };
 
+        self.possible_search_root = matches!(lexem, Some(Lexem::From))
+                || (matches!(lexem, Some(Lexem::Comma)) && !self.after_where);
         self.after_operator = matches!(lexem, Some(Lexem::Operator(_)));
 
         lexem
@@ -1072,7 +1076,7 @@ mod tests {
             lexer.next_lexem(),
             Some(Lexem::RawString(String::from("/test")))
         );
-        assert_eq!(lexer.next_lexem(), Some(Lexem::Group));
+        assert_eq!(lexer.next_lexem(), Some(Lexem::RawString("group".to_owned())));
         assert_eq!(lexer.next_lexem(), Some(Lexem::By));
         assert_eq!(
             lexer.next_lexem(),
